package com.fullertonindia.flutter_demo_lib;

import android.app.Activity;
import android.app.Dialog;
import android.content.ComponentName;
import android.content.Intent;

import java.io.UnsupportedEncodingException;
import java.security.NoSuchAlgorithmException;
import java.util.ArrayList;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/**
 * FlutterDemoLibPlugin
 */
public class FlutterDemoLibPlugin implements MethodCallHandler {
    private final Activity context;
    private MethodChannel channel;
    public static final int FDS_IMAGE_RESULT_CODE = 1234;
    MethodChannel.Result mResult;

    public FlutterDemoLibPlugin(Activity activity, MethodChannel channel) {
        this.context = activity;
        this.channel = channel;
        this.channel.setMethodCallHandler(this);
    }

    public static void registerWith(Registrar registrar) {
        final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_demo_lib");
        channel.setMethodCallHandler(new FlutterDemoLibPlugin(registrar.activity(), channel));
    }

    @Override
    public void onMethodCall(MethodCall call, Result result) {
        mResult = result;
        String greetings;
        switch (call.method) {
            case "getPlatformVersion":
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "showAlertDialog":
                Dialog dialog = new Dialog(context);
                dialog.setTitle("Hi, My Name is Flutter");
                dialog.show();
                result.success("Android " + android.os.Build.VERSION.RELEASE);
                break;
            case "getAESEncryptWithKey":
                greetings = GatewayUtils.getAESEncryptString((String)call.argument("param"), (String)call.argument("aesKey"));
                result.success(greetings);
                break;
            case "getAESDecryptWithKey":
                greetings = GatewayUtils.getAESDecryptString((String)call.argument("param"),(String) call.argument("aesKey"));
                result.success(greetings);
                break;
            case "getRSAEncryptString":
                greetings = GatewayUtils.getRSAEncryptString((String)call.argument("param"), (String)call.argument("rsaPublic"));
                result.success(greetings);
                break;
            case "generateAESKey":
                try {
                    greetings = GatewayUtils.generateAESKEY();
                    result.success(greetings);
                } catch (NoSuchAlgorithmException e) {
                    e.printStackTrace();
                }
                break;
            case "getDeviceMacAddress":
                try {
                    //greetings = getMAcAddress(getApplicationContext());
                    result.success("");
                } catch (Exception e) {
                    e.printStackTrace();
                }
                break;
            case "callFDSAndGetImages":
                try {
                    callFDSToCaptureImages((String)call.argument("encryptedData"));
                } catch (Exception e) {
                    e.printStackTrace();
                    mResult.success(new ArrayList<>());
                }
                break;
        }
    }

    private void callFDSToCaptureImages(String data) {
        try {
            Intent intent = new Intent(Intent.ACTION_MAIN);
            intent.setComponent(new ComponentName("com.fullertonindia.ficcdocscanner", "com.fullertonindia.ficcdocscanner.camscanner.advanced_camscanner.ChooseActivity"));
            intent.setFlags(0);
            intent.putExtra("watermark", data);
            context.startActivityForResult(intent, FDS_IMAGE_RESULT_CODE);
        } catch (Exception e) {
            mResult.success(new ArrayList<>());
            e.printStackTrace();
        }
    }

}
